# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class FileResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'is_folder': 'bool',
        'modified_date': 'str',
        'size': 'int',
        'path': 'str',
        'is_directory': 'bool'
    }

    attribute_map = {
        'name': 'Name',
        'is_folder': 'IsFolder',
        'modified_date': 'ModifiedDate',
        'size': 'Size',
        'path': 'Path',
        'is_directory': 'IsDirectory'
    }

    discriminator_value_class_map = {
        '': 'FileVersion'
    }

    def __init__(self, name=None, is_folder=None, modified_date=None, size=None, path=None, is_directory=None):
        """
        FileResponse - a model defined in Swagger
        """

        self._name = None
        self._is_folder = None
        self._modified_date = None
        self._size = None
        self._path = None
        self._is_directory = None
        self.discriminator = 'Type'

        if name is not None:
          self.name = name
        self.is_folder = is_folder
        self.modified_date = modified_date
        self.size = size
        if path is not None:
          self.path = path
        self.is_directory = is_directory

    @property
    def name(self):
        """
        Gets the name of this FileResponse.

        :return: The name of this FileResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FileResponse.

        :param name: The name of this FileResponse.
        :type: str
        """

        self._name = name

    @property
    def is_folder(self):
        """
        Gets the is_folder of this FileResponse.

        :return: The is_folder of this FileResponse.
        :rtype: bool
        """
        return self._is_folder

    @is_folder.setter
    def is_folder(self, is_folder):
        """
        Sets the is_folder of this FileResponse.

        :param is_folder: The is_folder of this FileResponse.
        :type: bool
        """
        if is_folder is None:
            raise ValueError("Invalid value for `is_folder`, must not be `None`")

        self._is_folder = is_folder

    @property
    def modified_date(self):
        """
        Gets the modified_date of this FileResponse.

        :return: The modified_date of this FileResponse.
        :rtype: str
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this FileResponse.

        :param modified_date: The modified_date of this FileResponse.
        :type: str
        """
        if modified_date is None:
            raise ValueError("Invalid value for `modified_date`, must not be `None`")

        self._modified_date = modified_date

    @property
    def size(self):
        """
        Gets the size of this FileResponse.

        :return: The size of this FileResponse.
        :rtype: int
        """
        return self._size

    @size.setter
    def size(self, size):
        """
        Sets the size of this FileResponse.

        :param size: The size of this FileResponse.
        :type: int
        """
        if size is None:
            raise ValueError("Invalid value for `size`, must not be `None`")

        self._size = size

    @property
    def path(self):
        """
        Gets the path of this FileResponse.

        :return: The path of this FileResponse.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this FileResponse.

        :param path: The path of this FileResponse.
        :type: str
        """

        self._path = path

    @property
    def is_directory(self):
        """
        Gets the is_directory of this FileResponse.

        :return: The is_directory of this FileResponse.
        :rtype: bool
        """
        return self._is_directory

    @is_directory.setter
    def is_directory(self, is_directory):
        """
        Sets the is_directory of this FileResponse.

        :param is_directory: The is_directory of this FileResponse.
        :type: bool
        """
        if is_directory is None:
            raise ValueError("Invalid value for `is_directory`, must not be `None`")

        self._is_directory = is_directory

    def get_real_child_model(self, data):
        """
        Returns the real base class specified by the discriminator
        """
        discriminator_value = data[self.discriminator].lower()
        if self.discriminator_value_class_map.has_key(discriminator_value):
            return self.discriminator_value_class_map[discriminator_value]
        else:
            return None

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, FileResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
