# coding: utf-8

"""
    Aspose.Storage for Cloud API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

    OpenAPI spec version: 1.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import sys
from setuptools import setup, find_packages

NAME = "asposestoragecloud"
VERSION = "1.0.4"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil", "chardet"]

setup(
    name=NAME,
    version=VERSION,
    description="Aspose.Storage for Cloud APIs",
    author_email="aspose.cloud@asposeptyltd.com",
    license='MIT',
    url="https://www.aspose.cloud/",
    keywords=["Aspose.Storage for Cloud APIs"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    Aspose.Storage for Cloud APIs https://apireference.aspose.cloud/storage/
    """
)
